API docs for “spamfighter.txjsonrpc.web.jsonrpc.Handler”

# Class s.t.w.j.Handler:

Part of spamfighter.txjsonrpc.web.jsonrpc View Source View In Hierarchy

Handle a JSON-RPC request and store the state for a request in progress.

Override the run() method and return result using self.result, a Deferred.

We require this class since we're not using threads, so we can't encapsulate state in a running function if we're going to have to wait for results.

For example, lets say we want to authenticate against twisted.cred, run a LDAP query and then pass its result to a database query, all as a result of a single JSON-RPC command. We'd use a Handler instance to store the state of the running command.

Method | __init__ | Undocumented
Method | run | Undocumented

def __init__(self, resource, *args): (source)
Undocumented
def run(self, *args): (source)
Undocumented